@@ -24,7 +24,5 @@ class Combiner(object):
 
         if not os.path.exists(output_file_name):
             logger.error("output file '%s' does not exist", output_file_name)
-            subprocess.call(["ls", "-la"])
-            subprocess.call(["pwd"])
 
         return returncode
